@@ -54,6 +54,13 @@ class SMTConfDetModuleDto extends SMTDto
      */    
     protected $monitoringTests = FALSE;
     
+    /**
+     * Whether module is compatible with detected switch
+     *
+     * @var boolean
+     */
+    protected $moduleCompatibleWithSwitch = TRUE;
+    
     /**
      * @return integer
      */
@@ -125,7 +132,25 @@ class SMTConfDetModuleDto extends SMTDto
     function isMonitoringTests()
     {
     	return $this->monitoringTests;
-    }   
+    }
+
+    /**
+     *
+     * @param boolean moduleCompatibleWithSwitch
+     */
+    function setModuleCompatibleWithSwitch( $moduleCompatibleWithSwitch)
+    {
+    	$this->moduleCompatibleWithSwitch= $moduleCompatibleWithSwitch;
+    }
+    
+    /**
+     *
+     * @return boolean moduleCompatibleWithSwitch
+     */
+    function isModuleCompatibleWithSwitch()
+    {
+    	return $this->moduleCompatibleWithSwitch;
+    }
     
     /**
      * 
