@@ -113,6 +113,7 @@ class SMTSwitchService extends SMTService implements SMTIService
     	    $configDetectSwitchDto->setOTAMPossible($this->getSwitchManager(TRUE)->isMolexSwitchPossible());
     	    $configDetectSwitchDto->setOTAMSwitch($this->getSwitchManager(TRUE)->hasMolexOSUDetected());
     	    $configDetectSwitchDto->setModuleCompatibleWithSwitch($this->getSwitchManager(TRUE)->isModuleCompatibleWithSwitch());
+    	    $configDetectSwitchDto->setPortDistributorNumber($this->switchManager->getPortsDistributorNumber());
     	}
     	catch ( \Exception $e )
     	{
@@ -161,6 +162,11 @@ class SMTSwitchService extends SMTService implements SMTIService
     		$configDetectSwitchDto->setOTAMPossible($this->switchManager->isMolexSwitchPossible());
     		$configDetectSwitchDto->setOTAMSwitch($this->switchManager->hasMolexOSUDetected());
     		$configDetectSwitchDto->setModuleCompatibleWithSwitch($this->switchManager->isModuleCompatibleWithSwitch());
+    		$configDetectSwitchDto->setPortDistributorNumber($this->switchManager->getPortsDistributorNumber());
+    		if ( $configDetectSwitchDto->getPortDistributorNumber() > 0 )
+    		{
+    		    $configDetectSwitchDto->setFixedPortDistributorNumber($this->switchManager->hasFixedPortsDistributor());
+    		}
     	}
     	catch ( \Exception $e )
     	{
@@ -283,6 +289,11 @@ class SMTSwitchService extends SMTService implements SMTIService
     		$osxList->setIsBigTopology($this->switchManager->isBigTopology());
     		$osxList->setIsOsxPowerOn($this->switchManager->getOsxPowerOn());
     		$osxList->setOTAMPossible($this->switchManager->isMolexSwitchPossible());
+    		$osxList->setPortDistributorNumber($this->switchManager->getPortsDistributorNumber());
+    		if ( $osxList->getPortDistributorNumber() > 0 )
+    		{
+    		    $osxList->setFixedPortDistributorNumber($this->switchManager->hasFixedPortsDistributor());
+    		}
     		$hasMolexOsu = FALSE;
     		$hasJdsuOSU = $this->switchManager->hasJdsuOSUDetected();
     		if ( !$hasJdsuOSU )
@@ -334,7 +345,8 @@ class SMTSwitchService extends SMTService implements SMTIService
     		$osxList->setIsBigTopology($this->switchManager->isBigTopology());
     		$osxList->setIsOsxPowerOn($this->switchManager->getOsxPowerOn());
     		$osxList->setOTAMPossible($this->switchManager->isMolexSwitchPossible());
-
+    		$osxList->setPortDistributorNumber($this->switchManager->getPortsDistributorNumber());
+    		
     		$osxList->computeSwitchType(!$otamScan, $otamScan);
     	}
     	catch ( \Exception $e )
@@ -376,15 +388,15 @@ class SMTSwitchService extends SMTService implements SMTIService
     
     /**
      *
-     * @url POST /osx/mode/{bigTopology}
+     * @url POST /osx/mode/{mode}
      *
      * @access protected
      * @class SMTAccessControl {@requires install}
      */
-    function setOsxBigTopology($bigTopology)
+    function setOsxMode($mode)
     {
     	try
-    	{
+    	{    	    
     		if ( $this->switchManager == NULL )
     		{
     			$this->switchManager = new SMTSwitchManager();
@@ -394,7 +406,28 @@ class SMTSwitchService extends SMTService implements SMTIService
     		//OSX setup in progress
     		$this->switchManager->disableSequencer(TRUE);
     		
-    		SMTSwitchManager::setBigTopology($bigTopology == 1? 'TRUE': 'FALSE', $this->getContext()->getOtuSocket() );
+    		switch( $mode)
+    		{
+    		    case SMTSwitchManager::OSX_MODE_ALL_DISTRIBUTOR:
+    		        SMTSwitchManager::setBigTopology('TRUE', $this->getContext()->getOtuSocket() );
+    		        SMTSwitchManager::setPortsDistributorNumber(0, $this->getContext()->getOtuSocket() );
+    		        break;
+    		    case SMTSwitchManager::OSX_MODE_1_DISTRIBUTOR:
+    		        SMTSwitchManager::setBigTopology('FALSE', $this->getContext()->getOtuSocket() );
+    		        SMTSwitchManager::setPortsDistributorNumber(1, $this->getContext()->getOtuSocket() );
+    		        break;
+    		    default:
+    		        if ( intval($mode) > intval(SMTSwitchManager::OSX_MODE_1_DISTRIBUTOR) )
+    		        {
+    		          SMTSwitchManager::setBigTopology('FALSE', $this->getContext()->getOtuSocket() );
+    		          SMTSwitchManager::setPortsDistributorNumber(intval($mode), $this->getContext()->getOtuSocket() );
+    		        }
+    		        else
+    		        {
+    		            throw new SMTInvalidValueException( SMTInvalidValueException::INVALID_VALUE, NULL, "osxMode = 0,1,4,8,12", intval($mode) );
+    		        }
+    		        break;
+    		}
     	}
     	catch ( \Exception $e )
     	{
@@ -439,8 +472,6 @@ class SMTSwitchService extends SMTService implements SMTIService
     	return $this->getOsxScan();
     }
     
-    
-    
     /**
      * 
      * @return \app\serviceshelper\otau\SMTSwitchManager
