@@ -47,6 +47,7 @@ use app\parser\SMTOtuApi;
 use app\serviceshelper\SMTServiceHelper;
 use app\services\alarm\otu\SMTOtuOpticalAlarmPeakDto;
 use app\services\alarm\SMTPeakOpticalAlarmDto;
+use app\http\SMTContext;
 
 /**
  * Helper class to retrieve and clear alarms.
@@ -121,7 +122,7 @@ class SMTAlarm extends SMTServiceHelper
                 				
                 			    try
                 			    {
-                			        $attenuationAlarm = self::processAttenuationAlarm($otuAlarm, $alarmDiscriminator, $dbConnection);
+                			        $attenuationAlarm = self::processAttenuationAlarm($otuAlarm, $alarmDiscriminator, $dbConnection, $this->getContext());
                                     if ( $attenuationAlarm != NULL )
                                     {
                                         array_push( $alarms, $attenuationAlarm );
@@ -159,7 +160,7 @@ class SMTAlarm extends SMTServiceHelper
                 						
                 						try
                 						{
-                							$peakAlarm= self::processPeakAlarm($otuAlarm, $peak, $alarmPeakDiscriminator, $dbConnection, $updateTraces);
+                							$peakAlarm= self::processPeakAlarm($otuAlarm, $peak, $alarmPeakDiscriminator, $dbConnection, $this->getContext(), $updateTraces);
                 							if ( $peakAlarm!= NULL )
                 							{
                 								$updateTraces = FALSE;
@@ -215,7 +216,7 @@ class SMTAlarm extends SMTServiceHelper
             	{
             	    //build alarm discriminators
             	    $alarmDiscriminator = SMTAlarmFactory::buildSystemAlarmDiscriminator( $otuAlarm );
-            	    $systemAlarm = self::processSystemAlarm($otuAlarm, $alarmDiscriminator, $dbConnection);
+            	    $systemAlarm = self::processSystemAlarm($otuAlarm, $alarmDiscriminator, $dbConnection, $this->getContext());
             	    if ( $systemAlarm != NULL )
             	    {
                         array_push( $alarms, $systemAlarm );
@@ -349,7 +350,7 @@ class SMTAlarm extends SMTServiceHelper
      * 
      * @return SMTAttenuationOpticalAlarmDto The created or update alarm. Returns NULL if the otu alarm was not processed.
      */
-    private static function processAttenuationAlarm( SMTOtuOpticalAlarmDto $otuAlarm, $alarmDiscriminator, SMTSmartOtuDB $dbConnection )    
+    private static function processAttenuationAlarm( SMTOtuOpticalAlarmDto $otuAlarm, $alarmDiscriminator, SMTSmartOtuDB $dbConnection, SMTContext $context )    
     {
         $alarm = NULL;
         
@@ -372,8 +373,8 @@ class SMTAlarm extends SMTServiceHelper
         	
         	//retrieve OTDR traces if they are available (not a test on demand on a link in alarm)
         	//copy the OTDR trace for a transition of the alarm (new alarm, alarm severity change... and back to normal (clear of the alarm) )
-        	if ( ($otuAlarm->getLocalisationFileName() != NULL && count($otuAlarm->getLocalisationFileName()) > 0 )|| 
-        			(($otuAlarm->getDetectionFileName() != NULL ) && count($otuAlarm->getDetectionFileName()) > 0 ) )
+        	if ( ($otuAlarm->getLocalisationFileName() != NULL && strlen($otuAlarm->getLocalisationFileName()) > 0 )|| 
+        	    (($otuAlarm->getDetectionFileName() != NULL ) && strlen($otuAlarm->getDetectionFileName()) > 0 ) )
         	{
         	    //first, remove the old trace
         	    SMTOtdrTraceFileUtil::removeOTUAlarmTraceFromSmartOtu( $otuAlarm->getTestId(), $alarmDiscriminator );
@@ -389,11 +390,11 @@ class SMTAlarm extends SMTServiceHelper
         	//create the alarm without its current event 
         	if ( $newAlarm )
         	{ 
-        	    $alarm = SMTAlarmFactory::createAttenuationOpticalAlarmDto( $dbConnection, $otuAlarm, $alarmDiscriminator );
+        	    $alarm = SMTAlarmFactory::createAttenuationOpticalAlarmDto( $context, $dbConnection, $otuAlarm, $alarmDiscriminator );
         	}
         	
         	//create the event and update the alarm with its current event if needed
-        	$alarmEvent = SMTAlarmFactory::updateAttenuationOpticalAlarmDto( $dbConnection, $otuAlarm, $alarm, $alarmDiscriminator, $newAlarm );
+        	$alarmEvent = SMTAlarmFactory::updateAttenuationOpticalAlarmDto( $context, $dbConnection, $otuAlarm, $alarm, $alarmDiscriminator, $newAlarm );
         	 
         	//save the alarm and the event
         	if ( $alarm != NULL )
@@ -427,7 +428,7 @@ class SMTAlarm extends SMTServiceHelper
      *
      * @return SMTAttenuationOpticalAlarmDto The created or update alarm. Returns NULL if the otu alarm was not processed.
      */
-    private static function processPeakAlarm( SMTOtuOpticalAlarmDto $otuAlarm, SMTOtuOpticalAlarmPeakDto $peakAlarmDto, $alarmDiscriminator, SMTSmartOtuDB $dbConnection, $updateTrace = FALSE )
+    private static function processPeakAlarm( SMTOtuOpticalAlarmDto $otuAlarm, SMTOtuOpticalAlarmPeakDto $peakAlarmDto, $alarmDiscriminator, SMTSmartOtuDB $dbConnection, SMTContext $context, $updateTrace = FALSE )
     {
     	$alarm = NULL;
     	
@@ -456,8 +457,8 @@ class SMTAlarm extends SMTServiceHelper
     		//retrieve OTDR traces if they are available (not a test on demand on a link in alarm)
     		//copy the OTDR trace for a transition of the alarm (new alarm, alarm severity change... and back to normal (clear of the alarm) )
     		if ( $updateTrace && 
-   				( ($otuAlarm->getLocalisationFileName() != NULL && count($otuAlarm->getLocalisationFileName()) > 0 )||
-				  (($otuAlarm->getDetectionFileName() != NULL ) && count($otuAlarm->getDetectionFileName()) > 0 ) ) ) 
+    		    ( ($otuAlarm->getLocalisationFileName() != NULL && strlen($otuAlarm->getLocalisationFileName()) > 0 )||
+    		        (($otuAlarm->getDetectionFileName() != NULL ) && strlen($otuAlarm->getDetectionFileName()) > 0 ) ) ) 
     		{
     			//first, remove the old trace
     			SMTOtdrTraceFileUtil::removeOTUAlarmTraceFromSmartOtu( $otuAlarm->getTestId(), $alarmPeakByTestDiscriminator);
@@ -473,11 +474,11 @@ class SMTAlarm extends SMTServiceHelper
     		//create the alarm without its current event
     		if ( $newAlarm )
     		{
-    			$alarm = SMTAlarmFactory::createPeakOpticalAlarmDto( $dbConnection, $otuAlarm, $peakAlarmDto, $alarmDiscriminator );
+    			$alarm = SMTAlarmFactory::createPeakOpticalAlarmDto( $context, $dbConnection, $otuAlarm, $peakAlarmDto, $alarmDiscriminator );
     		}
     		
     		//create the event and update the alarm with its current event if needed
-    		$alarmEvent = SMTAlarmFactory::updatePeakOpticalAlarmDto( $dbConnection, $otuAlarm, $peakAlarmDto, $alarm, $alarmDiscriminator, $newAlarm );
+    		$alarmEvent = SMTAlarmFactory::updatePeakOpticalAlarmDto( $context, $dbConnection, $otuAlarm, $peakAlarmDto, $alarm, $alarmDiscriminator, $newAlarm );
     		
     		//save the alarm and the event
     		if ( $alarm != NULL )
@@ -509,7 +510,7 @@ class SMTAlarm extends SMTServiceHelper
      * 
      * @return SMTOtuSystemAlarmDto The created or update alarm. Returns NULL is the otu alarm was not processed.
      */
-    private static function processSystemAlarm( SMTOtuSystemAlarmDto $otuAlarm, $alarmDiscriminator, SMTSmartOtuDB $dbConnection )
+    private static function processSystemAlarm( SMTOtuSystemAlarmDto $otuAlarm, $alarmDiscriminator, SMTSmartOtuDB $dbConnection, SMTContext $context )
     {
         $alarm = NULL;
         
@@ -537,7 +538,7 @@ class SMTAlarm extends SMTServiceHelper
         	//process system alarm
         	SMTLogger::getInstance()->trace( sprintf("Start system alarm processing for alarm discriminator: %s.", $alarmDiscriminator ),SMTLogger::DEBUG, __FILE__,__METHOD__,__LINE__ );
         	 
-        	$alarm = SMTAlarmFactory::createOrUpdateSystemAlarmDto( $dbConnection, $otuAlarm, $alarm, $alarmDiscriminator );
+        	$alarm = SMTAlarmFactory::createOrUpdateSystemAlarmDto( $context, $dbConnection, $otuAlarm, $alarm, $alarmDiscriminator );
         	 
         	//save alarm
         	if ( $alarm != NULL )
