@@ -50,7 +50,7 @@ class SMTLicence extends SMTServiceHelper
     /**
      * Remove software options from session (license is installed in ISU during upload)
      *
-     * @param $filename The name of the license file
+     * @param $filename string The name of the license file
      *
      */
     function processLicense($fileName)
@@ -66,9 +66,9 @@ class SMTLicence extends SMTServiceHelper
     /**
      * Load license file in ISU.
      *
-     * @param $filename The name of the license file
-     * @param $fullPath The full path name of the temporary file
-     * @throws Exception if process fails
+     * @param $filename string The name of the license file
+     * @param $fullPath string The full path name of the temporary file
+     * @throws \Exception if process fails
      */
     function installLicense($fileName, $fullPath)
     {
@@ -81,7 +81,7 @@ class SMTLicence extends SMTServiceHelper
     	        $command = sprintf(self::COPY_LICENSE_FILE_CMD, SMTUtil::escapeShellArgUtf8($fullPath) );
     	        SMTLogger::getInstance()->trace( sprintf("command: %s.", $command ), SMTLogger::DEBUG);
     	        
-    	        // update ssh keys
+    	        // update license
     	        $value = exec ($command, $output, $success);
     	        
     	        SMTLogger::getInstance()->trace(sprintf("copy uploaded license file output: %s success %s", $value, $success) );
@@ -135,7 +135,8 @@ class SMTLicence extends SMTServiceHelper
     	unset($_SESSION[SMTLicenseList::OTU_OPTION_TAPPING_MONITORING]);
     	unset($_SESSION[SMTLicenseList::OTU_OPTION_LIGHT_SOURCE]);
     	unset($_SESSION[SMTLicenseList::OTU_OPTION_REST_API]);
-    	unset($_SESSION[SMTLicenseList::OTU_OPTION_ULTRAFAST_MON]);	
+    	unset($_SESSION[SMTLicenseList::OTU_OPTION_ULTRAFAST_MON]);
+    	unset($_SESSION[SMTLicenseList::OTU_OPTION_VPN]);	
     }
     
     /**
@@ -143,7 +144,7 @@ class SMTLicence extends SMTServiceHelper
      *
      * @param SMTContext $context
      *
-     * @return whether the OTU has ssh key root access option.
+     * @return $sshKeyRootAccess whether the OTU has ssh key root access option.
      */
     static function isSshKeyRootAccessOption(SMTContext $context)
     {
@@ -174,7 +175,7 @@ class SMTLicence extends SMTServiceHelper
      *
      * @param SMTContext $context
      *
-     * @return whether the OTU is in High Security mode.
+     * @return $highSecurity whether the OTU is in High Security mode.
      */
     static function isHighSecurityMode(SMTContext $context)
     {
@@ -205,7 +206,7 @@ class SMTLicence extends SMTServiceHelper
      *
      * @param SMTContext $context
      *
-     * @return whether the OTU has peak monitoring option.
+     * @return $peakMonitoring whether the OTU has peak monitoring option.
      */
     static function isPeakMonitoringOption(SMTContext $context)
     {
@@ -236,7 +237,7 @@ class SMTLicence extends SMTServiceHelper
      *
      * @param SMTContext $context
      *
-     * @return whether the OTU has Tapping monitoring option.
+     * @return $tappingMonitoring whether the OTU has Tapping monitoring option.
      */
     static function isTappingMonitoringOption(SMTContext $context)
     {
@@ -268,7 +269,7 @@ class SMTLicence extends SMTServiceHelper
      *
      * @param SMTContext $context
      *
-     * @return whether the OTU has SAA monitoring option.
+     * @return $saa whether the OTU has SAA monitoring option.
      */
     static function isSaaOption(SMTContext $context)
     {
@@ -299,7 +300,7 @@ class SMTLicence extends SMTServiceHelper
      *
      * @param SMTContext $context
      *
-     * @return whether the OTU has REST API option.
+     * @return $RestApi whether the OTU has REST API option.
      */
     static function isRestApiOption(SMTContext $context)
     {
@@ -325,12 +326,43 @@ class SMTLicence extends SMTServiceHelper
     	return $RestApi;
     }
     
+    /**
+     * Test whether OTU has VPN option.
+     *
+     * @param SMTContext $context
+     *
+     * @return $vpn whether the OTU has VPN option.
+     */
+    static function isVpnOption(SMTContext $context)
+    {
+        $vpn = FALSE;
+        
+        if ( SMTSmartOtuSettings::isVpn() !== NULL )
+        {
+            $vpn= SMTSmartOtuSettings::isVpn();
+        }
+        else
+        {
+            try
+            {
+                $vpn = ( $context->getOtuSocket()->sendReceive( SMTOtuApi::isOtu_Vpn_Option() ) === self::OPTION_AVAILABLE);
+                
+                SMTSmartOtuSettings::setVpn($vpn);
+            }
+            catch ( \Exception $e )
+            {
+                SMTLogger::getInstance()->traceException( $e );
+            }
+        }
+        return $vpn;
+    }
+    
     /**
      * Returns the software options
      *
      * @param SMTContext $context
      *
-     * @return the list of software options as a string
+     * @return $softwareOptions the list of software options as a string
      */
     static function retrieveSoftwareOptions(SMTContext $context)
     {
@@ -340,9 +372,10 @@ class SMTLicence extends SMTServiceHelper
             $socketManager = new SMTOtuSocketManager( $context );
             //retrieve connection from the socket manager
             $socket = $socketManager->openSocket( SMTOtuSocket::ISU_PORT );
-            $softwareOptions = $socket->sendReceive(SMTOtuApi::getOtuLicensesFromIsu());
+            $softwareOptions = $socket->sendReceive(SMTOtuApi::getOtuLicensesFromIsu(), 10);
             if (SMTOtuType::isOtu8KV2() || SMTOtuType::isMts8KV2())
             {
+            $softwareOptions = $softwareOptions.",".$socket->sendReceive(SMTOtuApi::getOtauLicensesFromIsu());
             $softwareOptions = $softwareOptions.",".$socket->sendReceive(SMTOtuApi::getSensingLicensesFromIsu());
             }
             else if (SMTOtuType::isCOtu_EOTDRV2())
@@ -384,7 +417,7 @@ class SMTLicence extends SMTServiceHelper
      *
      * @param SMTContext $context
      *
-     * @return the list of software options with their status
+     * @return $softwareOptions the list of software options with their status
      */
     static function retrieveSoftwareOptionList(SMTContext $context, SMTLicenseListDto $licenseList)
     {
@@ -406,11 +439,18 @@ class SMTLicence extends SMTServiceHelper
 	    			$status = $context->getOtuSocket()->sendReceive( SMTOtuApi::getOtu_Option_Status($option) );
 	    			
 	    			//$name = $context->getOtuSocket()->sendReceive( SMTOtuApi::getOtu_Option_Name($option) );
+	    			$payg_license_count = self::getPayg_Option_Value( $context, $option, $status );
 	    			$license = new SMTLicenseDto();
 	    			$license->setSoftwareOption($option);
 	    			$license->setSoftwareOptionStatus($status);
-	    			$license->setSoftwareOptionName($name);
-	    			
+	    			if ( $payg_license_count > 0 )
+	    			{
+	    			    $license->setSoftwareOptionName($name.' x'.$payg_license_count.'');
+	    			}
+	    			else
+	    			{
+	    			    $license->setSoftwareOptionName($name);
+	    			}
 	    			$licenseList->addLicense( $license );
     			}
     		}
@@ -425,5 +465,31 @@ class SMTLicence extends SMTServiceHelper
     	return $softwareOptions;
     }
     
+    /**
+     * Returns the software options PAYG license count
+     *
+     * @param SMTContext $context
+     *
+     * @return $optionValue the software options PAYG license count
+     */
+    static function getPayg_Option_Value( SMTContext $context, $option, $status )
+    {
+        $optionValue = 0;
+        if ( !SMTOtuType::isCOtu_EOTDRV2() && strcmp($status, 'IMPOSSIBLE') !=0 )
+        {
+            if ( strcasecmp( $option, SMTLicenseList::OTU_OPTION_PAYG_PORT12) == 0)
+            {
+                try
+                {
+                    $optionValue = intval($context->getOtuSocket()->sendReceive( SMTOtuApi::getOtu_PAYG_Internal_Switch_Lic_Count()) );                    
+                }
+                catch ( \Exception $e )
+                {
+                    SMTLogger::getInstance()->traceException( $e );
+                }
+            }
+        }
+        return $optionValue;        
+    }
 }
 ?>
