@@ -32,6 +32,8 @@ final class SMTLicenseList
 	const LIGHT_SOURCE= 'LIGHT_SOURCE';
 	const REST_API= 'REST_API';
 	const ULTRAFAST_MON='ULTRAFAST_MON';
+	const OTU_VPN='OTU_VPN';
+	const OTU_PAYG_PORT12='PAYG_PORT012';
 	
 	const OTU_OPTION_HIGH_SEC = 'HIGHSEC';
 	const OTU_OPTION_SSH_KEY_ACCESS = 'ACCESS';
@@ -44,6 +46,8 @@ final class SMTLicenseList
 	const OTU_OPTION_LIGHT_SOURCE= 'LIGHT_SOURCE';
 	const OTU_OPTION_REST_API= 'REST_API';
     const OTU_OPTION_ULTRAFAST_MON='ULTRAFAST_MON';
+    const OTU_OPTION_VPN='OTU_VPN';
+    const OTU_OPTION_PAYG_PORT12='PAYG_PORT012';
 
 	const ISU_OPTION_SAA_L2_MONITORING = 'SMART_ACCESS_L2';
 	
@@ -66,36 +70,13 @@ final class SMTLicenseList
 			                            self::OTU_OPTION_TAPPING_MONITORING=>self::TAPPING_MON,
 										self::OTU_OPTION_LIGHT_SOURCE=>self::LIGHT_SOURCE,
 										self::OTU_OPTION_REST_API=>self::REST_API,
-	                                    self::OTU_OPTION_ULTRAFAST_MON=>self::ULTRAFAST_MON
+	                                    self::OTU_OPTION_ULTRAFAST_MON=>self::ULTRAFAST_MON,
+	                                    self::OTU_OPTION_VPN=>self::OTU_VPN,
+	                                    self::OTU_OPTION_PAYG_PORT12=>self::OTU_PAYG_PORT12
 	);
 	
 	static function getLicenseName( $scpiKey )
 	{
-// 		$licenseName ="";
-// 		switch($scpiKey)
-// 		{
-// 			case self::OTU_OPTION_HIGH_SEC:
-// 				$licenseName = self::ENHANCEDSECURITY;
-// 				break;
-// 			case self::OTU_OPTION_SSH_KEY_ACCESS:
-// 				$licenseName = self::SSH_KEY_ACCESS;
-// 				break;
-// 			case self::OTU_OPTION_PEAK_MONITORING:
-// 				$licenseName = self::PEAK_MON;
-// 				break;
-// 			case self::OTU_OPTION_DUAL_OS_MONITORING:
-// 				$licenseName = self::DUAL_OS;
-// 				break;
-// 			case self::OTU_OPTION_EXT_TEMP_RANGE_MONITORING:
-// 				$licenseName = self::EXT_TEMP_RANGE;
-// 				break;
-// 			case self::OTU_OPTION_TEST_PON_MONITORING:
-// 				$licenseName = self::PON_TEST;
-// 				break;
-// 			case self::OTU_OPTION_SAA_L2_MONITORING:
-// 				$licenseName = self::SAA;
-// 				break;
-// 		}
 		return self::$OTU_OPTIONS[$scpiKey];
 	}
 	
