@@ -13,6 +13,7 @@
 // *********************************************************
 namespace app\serviceshelper\otau;
 
+use app\parser\SMTOtuApi;
 use app\parser\SMTOtuSocket;
 use app\services\setup\SMTSwitchDto;
 
@@ -83,6 +84,20 @@ abstract class SMTMacroSwitch
     */
     protected $serialNumber;
     
+    /**
+     * Internal Switch has licence
+     *
+     * @var boolean
+     */
+    protected $internalSwitchHasLicense = FALSE;
+    
+    /**
+     * Internal Switch total outputs
+     *
+     * @var integer
+     */
+    protected $internalSwitchOutPut = 1;    
+    
     /**
      * 
      * @param app\parser\SMTOtuSocket $socket
@@ -181,6 +196,16 @@ abstract class SMTMacroSwitch
     		$switchDto->setOutput( $decoder->getOut() );
     		$switchDto->setGlobalSwitchEncodedString($this->globalSwitchEncodedString);
     		
+    		if ( $this->internalSwitchHasLicense )
+    		{
+    		    $switchDto->setLicense($this->internalSwitchHasLicense);
+    		    $switchDto->setTotalNumberOfPorts( $this->internalSwitchOutPut );
+    		}
+    		else 
+    		{
+    		    $switchDto->setTotalNumberOfPorts( $decoder->getOut() );
+    		}
+    		
     		array_push($this->switchesDto, $switchDto);
     	}    	
     	
@@ -196,6 +221,7 @@ abstract class SMTMacroSwitch
     	        
     	    	$switchDto->setInput( $decoder->getIn() );
     	    	$switchDto->setOutput( $decoder->getOut() );
+    	    	$switchDto->setTotalNumberOfPorts( $decoder->getOut() );
     	    	
     	    	$switchDto->setGlobalSwitchEncodedString($this->globalSwitchEncodedString);
     	    	
@@ -213,6 +239,7 @@ abstract class SMTMacroSwitch
 		        
 		    	$switchDto->setInput( $decoder->getIn() );
 		    	$switchDto->setOutput( $decoder->getOut() );
+		    	$switchDto->setTotalNumberOfPorts( $decoder->getOut() );
 		    	
 		    	$switchDto->setGlobalSwitchEncodedString($this->globalSwitchEncodedString);
 		    	
@@ -256,6 +283,36 @@ abstract class SMTMacroSwitch
     {
     	return ($this->getSwitchDecoder( self::GLOB) != NULL)? $this->getSwitchDecoder( self::GLOB)->hasMolexOSU(): FALSE;
     }
+    
+    /**
+     * Whether the topology uses ports distributor at the end
+     *
+     * @return boolean
+     */
+    function hasPortsDistributorAtEnd()
+    {
+        return ($this->getSwitchDecoder( self::GLOB) != NULL)? $this->getSwitchDecoder( self::GLOB)->hasPortsDistributorAtEnd(): FALSE;
+    }
+    
+    /**
+     * Number of ports at the end used for distribution.
+     *
+     * @return int  Number of ports at the end used for distribution.
+     */
+    function getPortDistributorNumber()
+    {
+        return ($this->getSwitchDecoder( self::GLOB) != NULL)? $this->getSwitchDecoder( self::GLOB)->getPortDistributorNumber(): 0;
+    }
+    
+    function isInternalSwitchWithLicence()
+    {
+        return strcasecmp( 'TRUE', $this->socket->sendReceive( SMTOtuApi::CMD_Has_Internal_Switch_License) ) == 0;
+    }
+    
+    function getInternalSwitchTotalPorts()
+    {
+        return intval($this->socket->sendReceive( SMTOtuApi::CMD_Get_Internal_Switch_Total_Ports ) );
+    }
 }
 
 ?>
\ No newline at end of file
