@@ -52,6 +52,12 @@ class SMTMacroSwitchConf extends SMTMacroSwitch
         	$nbOsx = self::OSU_DISTRIBUTOR_INDEX -1 ;
         }
         
+        if ( $this->getSwitchDecoder( parent::GLOB)->hasPortsDistributorAtEnd() )
+        {
+            $result = $this->socket->sendReceive( SMTOtuApi::CMD_get_Nb_Port_Distributeur );
+            $this->getSwitchDecoder( parent::GLOB)->setPortDistributorNumber( intval( $result ) );
+        }
+        
         //retrieve OSU if needed: WARNING only retrieve OSU1 and OSU2 in simplified mode
         for ( $osuCount = 1; $osuCount <= $nbOsx; $osuCount++)
         {
@@ -92,8 +98,11 @@ class SMTMacroSwitchConf extends SMTMacroSwitch
                 $this->setSwitchDecoder( parent::INTERNAL, $code );        
                 $this->serialNumber = $this->socket->sendReceive( sprintf( SMTOtuApi::CMD_switch_config_SerialNum, SMTSwitchManager::MACRO_SWITCH_ID, parent::INTERNAL ) );
                 
-                //not used
-                //$ports = $this->switchManager->sendReceive( sprintf( SMTOtuApi::CMD_get_switch_ports, parent::INTERNAL_POSITION ) );
+                $this->internalSwitchHasLicense = $this->isInternalSwitchWithLicence();
+                if ( $this->internalSwitchHasLicense )
+                {
+                    $this->internalSwitchOutPut = $this->getInternalSwitchTotalPorts();
+                }
             }
         }                
     }
