@@ -13,7 +13,8 @@
 // *********************************************************
 namespace app\util;
 
-use app\serviceshelper\system\SMTSystemConfigurationDto;
+use app\serviceshelper\system\SMTOtu;
+use app\http\SMTContext;
 
 class SMTUtil
 {   
@@ -54,6 +55,7 @@ class SMTUtil
      */
     public static function splitStringByComma( $stringToSplit )
     {
+        $matches = array();
 //         SMTLogger::getInstance()->trace($stringToSplit);
         preg_match_all("/(\"[^\"]+\"|[^,]+)/", $stringToSplit, $matches );
 //         SMTLogger::getInstance()->trace(self::serialize_array( $matches[0] ));
@@ -187,7 +189,7 @@ class SMTUtil
      *
      * @return integer/float timestamp in seconds and in UTC
      */
-    public static function getTimestampUTC( $otuTimestamp, \SQLite3 $dbConnection, $timezoneOffset = NULL )
+    public static function getTimestampUTC( $otuTimestamp, SMTContext $context, $timezoneOffset = NULL )
     {
     	$timestamp = ( isset( $otuTimestamp) && self::isInt( $otuTimestamp) )? self::convertToInt( $otuTimestamp ): NULL;
     
@@ -196,8 +198,10 @@ class SMTUtil
         	//retrieve timezone offset from database settings if it is not given
         	if ( $timezoneOffset === NULL )
         	{
-            	$dto = SMTSystemConfigurationDto::fetch($dbConnection);
-            	$timezoneOffset = $dto->getTimezoneSec();
+//              $dto = SMTSystemConfigurationDto::fetch($dbConnection);
+//             	$timezoneOffset = $dto->getTimezoneSec();
+
+        	    $timezoneOffset = SMTOtu::getTimeZoneOffsetSec( $context);
         	}
         	if ( isset($timezoneOffset) &&  $timezoneOffset != NULL )
         	{
@@ -220,7 +224,7 @@ class SMTUtil
      *
      * @return integer/float timestamp in current timezone
      */
-    public static function getTimestamp( $timestampUtc, \SQLite3 $dbConnection, $timezoneOffset = NULL )
+    public static function getTimestamp( $timestampUtc, SMTContext $context, $timezoneOffset = NULL )
     {
     	$timestamp = $timestampUtc;
     
@@ -229,8 +233,10 @@ class SMTUtil
     		//retrieve timezone offset from database settings if it is not given
     		if ( $timezoneOffset === NULL )
     		{
-    			$dto = SMTSystemConfigurationDto::fetch($dbConnection);
-    			$timezoneOffset = $dto->getTimezoneSec();
+//     			$dto = SMTSystemConfigurationDto::fetch($dbConnection);
+//     			$timezoneOffset = $dto->getTimezoneSec();
+    			
+    			$timezoneOffset = SMTOtu::getTimeZoneOffsetSec( $context);
     		}
     		if ( isset($timezoneOffset) &&  $timezoneOffset != NULL )
     		{
@@ -293,5 +299,49 @@ class SMTUtil
     {
     	return ( ($arg !== NULL) && isset($arg) && ("\0" != $arg) )? str_replace("'", "'\\''", $arg) : "";
     }
+    
+    /**
+     * Return Linux timezone name
+     *
+     * @return string
+     */
+    public static function getSystemTimeZone()
+    {
+        $timezone = 'UTC';
+        if ( is_link("/etc/localtime") ) 
+        {
+            
+            // If it is, that file's name is actually the "Olsen" format timezone
+            $filename = readlink("/etc/localtime");
+            
+            $pos = strpos($filename, "zoneinfo");
+            if ($pos) 
+            {
+                // When it is, it's in the "/usr/share/zoneinfo/" folder
+                $timezone = substr($filename, $pos + strlen("zoneinfo/"));
+            } 
+            
+        }
+        return $timezone;
+    }
+    
+    /**
+     * Buld timezone from Linux
+     *
+     * @return string
+     */
+    public static function createSystemTimeZone()
+    {
+        $timezone = NULL;
+        try 
+        {
+            $timezone = new \DateTimeZone(self::getSystemTimeZone());
+        } 
+        catch (\Exception $e) 
+        {
+            error_log($e->getMessage());
+        }
+        return $timezone;         
+    }
 }
 ?>
\ No newline at end of file
