@@ -4,7 +4,7 @@ try:
 except ImportError:
     from .c_struct import read_struct_from_file, write_struct_to_file
     from .calib_type import CommonHeader
-from jdsu.mts.blockutils import mount_cal, umount_cal
+from jdsu.mts.blockutils import mount_cal, umount_cal, is_mount
 import datetime, os
 
 PLATFORM_MTS4000NG = {
@@ -100,20 +100,23 @@ def cal_set_header(cal, field, serial):
 def cal_get_base_calibration():
     import os.path
     calmount = False
-    try:
-        calmount = mount_cal()
-    except:
-        pass
+
+    if not is_mount("/cal"):
+        try:
+            calmount = mount_cal()
+        except:
+            pass
 
     if os.path.exists("/cal/board_info.bin"):
         cal = read_struct_from_file("/cal/board_info.bin", CommonHeader)
     else:
         cal = CommonHeader()
 
-    try:
-        umount_cal(calmount)
-    except:
-        return False
+    if calmount != False:
+        try:
+            umount_cal(calmount)
+        except:
+            return False
 
     return cal
 
