@@ -351,15 +351,18 @@ def show_diff(url, proxy):
                     dist_item.attrib["name"], dist_item.attrib["version"].replace("V", ""), "/".join(d)))
 
         for current_provide in current_xml.xpath("content/provide"):
-            dist_provide = dist_xml.xpath("content/provide[@name='%s']" % current_provide.attrib["name"])[0]
-            d = dist_provide.attrib["date"].split("-")
-            d.reverse()
-            if int(current_provide.attrib["version"]) != int(dist_provide.attrib["version"]):
-                tmp.append("ISU: RELEASE : \"%-20s\" ! %15s %s" % (
-                    dist_provide.attrib["name"], dist_provide.attrib["version"].replace("V", ""), "/".join(d)))
-            else:
-                tmp.append("ISU: RELEASE : \"%-20s\" = %15s %s" % (
-                    dist_provide.attrib["name"], dist_provide.attrib["version"].replace("V", ""), "/".join(d)))
+            try:
+                dist_provide = dist_xml.xpath("content/provide[@name='%s']" % current_provide.attrib["name"])[0]
+                d = dist_provide.attrib["date"].split("-")
+                d.reverse()
+                if int(current_provide.attrib["version"]) != int(dist_provide.attrib["version"]):
+                    tmp.append("ISU: RELEASE : \"%-20s\" ! %15s %s" % (
+                        dist_provide.attrib["name"], dist_provide.attrib["version"].replace("V", ""), "/".join(d)))
+                else:
+                    tmp.append("ISU: RELEASE : \"%-20s\" = %15s %s" % (
+                        dist_provide.attrib["name"], dist_provide.attrib["version"].replace("V", ""), "/".join(d)))
+            except:
+                pass
     if not valid:
         tmp.append("ISU: RPM     : \"Corrupted Media !!!\"")
 
