@@ -732,14 +732,14 @@ class ManualSchema(Schema):
 #     """
 #     Schema for the configuration of a Radio Analysis Spectrum Analyzer Sweep Tuned Spectrum test
 #     """
-#     test_type = test_type_factory('RF ACLR')
+#     test_type = test_type_factory('RF Adjacent Channel Power')
 #     config_file = config_factory('/user/cellAdvisor5G/internal/StrataSync/')
 #
 # class RASAMultiAdjacentChannelPower(Schema):
 #     """
 #     Schema for the configuration of a Radio Analysis Spectrum Analyzer Sweep Tuned Spectrum test
 #     """
-#     test_type = test_type_factory('RF Multi-ACLR')
+#     test_type = test_type_factory('RF Multi Adjacent Channel Power')
 #     config_file = config_factory('/user/cellAdvisor5G/internal/StrataSync/')
 #
 # class RASASpuriousEmissions(Schema):
@@ -921,14 +921,14 @@ class ManualSchema(Schema):
 #     """
 #     Schema for the configuration of a Radio Analysis Spectrum Analyzer Sweep Tuned Spectrum test
 #     """
-#     test_type = test_type_factory('LTE TDD ACLR')
+#     test_type = test_type_factory('LTE TDD Adjacent Channel Power')
 #     config_file = config_factory('/user/cellAdvisor5G/internal/StrataSync/')
 #
 # class RALTETDDMultiAdjacentChannelPower(Schema):
 #     """
 #     Schema for the configuration of a Radio Analysis Spectrum Analyzer Sweep Tuned Spectrum test
 #     """
-#     test_type = test_type_factory('LTE TDD Multi-ACLR')
+#     test_type = test_type_factory('LTE TDD Multi Adjacent Channel Power')
 #     config_file = config_factory('/user/cellAdvisor5G/internal/StrataSync/')
 #
 # class RALTETDDSpuriousEmissions(Schema):
@@ -1082,14 +1082,14 @@ class ManualSchema(Schema):
 #     """
 #     Schema for the configuration of a Radio Analysis Spectrum Analyzer Sweep Tuned Spectrum test
 #     """
-#     test_type = test_type_factory('LTE FDD ACLR')
+#     test_type = test_type_factory('LTE FDD Adjacent Channel Power')
 #     config_file = config_factory('/user/cellAdvisor5G/internal/StrataSync/')
 #
 # class RALTEFDDMultiAdjacentChannelPower(Schema):
 #     """
 #     Schema for the configuration of a Radio Analysis Spectrum Analyzer Sweep Tuned Spectrum test
 #     """
-#     test_type = test_type_factory('LTE FDD Multi-ACLR')
+#     test_type = test_type_factory('LTE FDD Multi Adjacent Channel Power')
 #     config_file = config_factory('/user/cellAdvisor5G/internal/StrataSync/')
 #
 # class RALTEFDDSpuriousEmissions(Schema):
@@ -1243,14 +1243,14 @@ class ManualSchema(Schema):
 #     """
 #     Schema for the configuration of a Radio Analysis Spectrum Analyzer Sweep Tuned Spectrum test
 #     """
-#     test_type = test_type_factory('5G NR ACLR')
+#     test_type = test_type_factory('5G NR Adjacent Channel Power')
 #     config_file = config_factory('/user/cellAdvisor5G/internal/StrataSync/')
 #
 # class RA5GNRMultiAdjacentChannelPower(Schema):
 #     """
 #     Schema for the configuration of a Radio Analysis Spectrum Analyzer Sweep Tuned Spectrum test
 #     """
-#     test_type = test_type_factory('5G NR Multi-ACLR')
+#     test_type = test_type_factory('5G NR Multi Adjacent Channel Power')
 #     config_file = config_factory('/user/cellAdvisor5G/internal/StrataSync/')
 #
 # class RA5GNRSpuriousEmissions(Schema):
@@ -1445,8 +1445,10 @@ CONFIG_SCHEMAS = {'CPRI Check': CpriCheckConfigSchema,
                   'RF Channel Power' : caa.RASAChannelPower,
                   'RF Occupied Bandwidth' : caa.RASAOccupiedBandwidth,
                   'RF Spectrum Emission Mask' : caa.RASASpectrumEmissionMask,
-                  'RF ACLR' : caa.RASAAdjacentChannelPower,
-                  'RF Multi-ACLR' : caa.RASAMultiAdjacentChannelPower,
+                  'RF ACLR' : caa.RASAACLR,
+                  'RF Adjacent Channel Power' : caa.RASAAdjacentChannelPower,
+                  'RF Multi-ACLR' : caa.RASAMultiACLR,
+                  'RF Multi Adjacent Channel Power' : caa.RASAMultiAdjacentChannelPower,
                   'RF Spurious Emissions' : caa.RASASpuriousEmissions,
                   'RF Total Harmonic Distortion' : caa.RASATotalHarmonicDistortion,
                   'RF Field Strength' : caa.RASAFieldStrength,
@@ -1472,8 +1474,8 @@ CONFIG_SCHEMAS = {'CPRI Check': CpriCheckConfigSchema,
                   'LTE TDD Channel Power' : caa.RALTETDDChannelPower,
                   'LTE TDD Occupied Bandwidth' : caa.RALTETDDOccupiedBandwidth,
                   'LTE TDD Spectrum Emission Mask' : caa.RALTETDDSpectrumEmissionMask,
-                  'LTE TDD ACLR' : caa.RALTETDDAdjacentChannelPower,
-                  'LTE TDD Multi-ACLR' : caa.RALTETDDMultiAdjacentChannelPower,
+                  'LTE TDD Adjacent Channel Power' : caa.RALTETDDAdjacentChannelPower,
+                  'LTE TDD Multi Adjacent Channel Power' : caa.RALTETDDMultiAdjacentChannelPower,
                   'LTE TDD Spurious Emissions' : caa.RALTETDDSpuriousEmissions,
                   'LTE TDD Power vs Time (Frame)' : caa.RALTETDDPowerVsTimeFrame,
                   'LTE TDD Power vs Time (Slot)' : caa.RALTETDDPowerVsTimeSlot,
@@ -1490,13 +1492,14 @@ CONFIG_SCHEMAS = {'CPRI Check': CpriCheckConfigSchema,
                   'LTE TDD OTA Control Channel' : caa.RALTETDDOTAControlChannel,
                   'LTE TDD OTA Datagram' : caa.RALTETDDOTADatagram,
                   'LTE TDD OTA Route Map' : caa.RALTETDDOTARouteMap,
+                  'LTE TDD Freq / Time Error Variation' : caa.RALTETDDFreqTimeErrorVariation,
                   'LTE TDD Power Statistics CCDF' : caa.RALTETDDPowerStatisticsCCDF,
                   'LTE FDD Spectrum': caa.RALTEFDDSpectrum,
                   'LTE FDD Channel Power' : caa.RALTEFDDChannelPower,
                   'LTE FDD Occupied Bandwidth' : caa.RALTEFDDOccupiedBandwidth,
                   'LTE FDD Spectrum Emission Mask' : caa.RALTEFDDSpectrumEmissionMask,
-                  'LTE FDD ACLR' : caa.RALTEFDDAdjacentChannelPower,
-                  'LTE FDD Multi-ACLR' : caa.RALTEFDDMultiAdjacentChannelPower,
+                  'LTE FDD Adjacent Channel Power' : caa.RALTEFDDAdjacentChannelPower,
+                  'LTE FDD Multi Adjacent Channel Power' : caa.RALTEFDDMultiAdjacentChannelPower,
                   'LTE FDD Spurious Emissions' : caa.RALTEFDDSpuriousEmissions,
                   'LTE FDD Power vs Time (Frame)' : caa.RALTEFDDPowerVsTimeFrame,
                   'LTE FDD Power vs Time (Slot)' : caa.RALTEFDDPowerVsTimeSlot,
@@ -1513,20 +1516,48 @@ CONFIG_SCHEMAS = {'CPRI Check': CpriCheckConfigSchema,
                   'LTE FDD OTA Control Channel' : caa.RALTEFDDOTAControlChannel,
                   'LTE FDD OTA Datagram' : caa.RALTEFDDOTADatagram,
                   'LTE FDD OTA Route Map' : caa.RALTEFDDOTARouteMap,
+                  'LTE FDD Freq / Time Error Variation' : caa.RALTEFDDFreqTimeErrorVariation,
                   'LTE FDD Power Statistics CCDF' : caa.RALTEFDDPowerStatisticsCCDF,
                   '5G NR Trigger Spectrum' : caa.RA5GNRTriggerSpectrum,
                   '5G NR Channel Power' : caa.RA5GNRChannelPower,
                   '5G NR Occupied Bandwidth' : caa.RA5GNROccupiedBandwidth,
                   '5G NR Spectrum Emission Mask' : caa.RA5GNRSpectrumEmissionMask,
-                  '5G NR ACLR' : caa.RA5GNRAdjacentChannelPower,
-                  '5G NR Multi-ACLR' : caa.RA5GNRMultiAdjacentChannelPower,
+                  '5G NR Adjacent Channel Power' : caa.RA5GNRAdjacentChannelPower,
+                  '5G NR Multi Adjacent Channel Power' : caa.RA5GNRMultiAdjacentChannelPower,
                   '5G NR Spurious Emissions' : caa.RA5GNRSpuriousEmissions,
                   '5G NR Beam Analyzer' : caa.RA5GNRBeamAnalyzer,
                   '5G NR Carrier Scanner' : caa.RA5GNRCarrierScanner,
                   '5G NR Route Map' : caa.RA5GNRRouteMap,
                   '5G NR Beam Availability Index' : caa.RA5GNRBeamAvailabilityIndex,
+                  '5G NR Freq / Time Error Variation' : caa.RA5GNRFreqTimeErrorVariation,
                   '5G NR Power vs Time (Symbol)' : caa.RA5GNRPowerVsTimeSymbol,
                   '5G NR Power vs Time (Frame)' : caa.RA5GNRPowerVsTimeFrame,
+                  'EMF Spectrum' : caa.RAEMFSpectrum,
+                  'EMF 5G NR Beam Analysis' : caa.RAEMF5GNRBeamAnalysis,
+                  'DSS Spectrum' : caa.RADSSSpectrum,
+                  'DSS Channel Power' : caa.RADSSChannelPower,
+                  'DSS Occupied Bandwidth' : caa.RADSSOccupiedBandwidth,
+                  'DSS Spectrum Emission Mask' : caa.RADSSSpectrumEmissionMask,
+                  'DSS Adjacent Channel Power' : caa.RADSSAdjacentChannelPower,
+                  'DSS Multi Adjacent Channel Power' : caa.RADSSMultiAdjacentChannelPower,
+                  'DSS Spurious Emissions' : caa.RADSSSpuriousEmissions,
+                  'DSS Power vs Time (Frame)' : caa.RADSSPowerVsTimeFrame,
+                  'DSS Power vs Time (Slot)' : caa.RADSSPowerVsTimeSlot,
+                  'DSS Constellation' : caa.RADSSConstellation,
+                  'DSS Channel Mapper' : caa.RADSSChannelMapper,
+                  'DSS Control Channel' : caa.RADSSControlChannel,
+                  'DSS Subframe' : caa.RADSSSubframe,
+                  'DSS Frame' : caa.RADSSFrame,
+                  'DSS Time Alignment Error' : caa.RADSSTimeAlignmentError,
+                  'DSS OTA Channel Scanner' : caa.RADSSOTAChannelScanner,
+                  'DSS OTA ID Scanner' : caa.RADSSOTAIDScanner,
+                  'DSS OTA Multipath Profile' : caa.RADSSOTAMultipathProfile,
+                  'DSS OTA Control Channel' : caa.RADSSOTAControlChannel,
+                  'DSS OTA Route Map' : caa.RADSSOTARouteMap,
+                  'DSS Freq / Time Error Variation' : caa.RADSSFreqTimeErrorVariation,
+                  'NSA Analyzer' : caa.RANSAAnalyzer,
+                  'NSA Scanner' : caa.RANSAScanner,
+                  'NSA Route Map' : caa.RANSARouteMap,
                   'RFPM Internal RF Power Meter' : caa.RARFInternalPowerMeter,
                   'RFPM External RF Power Meter' : caa.RARFExternalPowerMeter,
                   'RFoCPRI Spectrum' : caa.RARFoCPRISpectrum,
