@@ -1,5 +1,5 @@
-from jdsu.evm import *
-from jdsu.diag import *
+from viavi.evm import *
+from viavi.diag import *
 from time import time, sleep
 from jdsu.mts.uts_bdt import UtsBdt
 from jdsu.mts.evdev import InputDevice
